@@ -6,19 +6,19 @@
     <message>
         <location filename="../mainwindow.ui" line="14"/>
         <location filename="../mainwindow.cpp" line="45"/>
-        <location filename="../mainwindow.cpp" line="302"/>
+        <location filename="../mainwindow.cpp" line="303"/>
         <source>MX Conky</source>
-        <translation type="unfinished"></translation>
+        <translation>MX Conky</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="20"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;This app enables detailed changes to the active conky. It supplements Conky Manager, which should be used for basic settings.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;Ta aplikacja umożliwia szczegółowe zmiany aktywnego Conky. Uzupełnia ona Menedżera Conky, który powinien być używany do podstawowych ustawień.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="73"/>
         <source>Launch</source>
-        <translation type="unfinished"></translation>
+        <translation>Uruchamianie</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="85"/>
@@ -33,47 +33,47 @@
     <message>
         <location filename="../mainwindow.ui" line="171"/>
         <source>Edit</source>
-        <translation type="unfinished"></translation>
+        <translation>Edytuj</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="185"/>
         <source>Conky Name</source>
-        <translation type="unfinished"></translation>
+        <translation>Nazwa Conky</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="211"/>
         <source>Conky Manager</source>
-        <translation type="unfinished"></translation>
+        <translation>Menedżer Conky</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="235"/>
         <source>Drag</source>
-        <translation type="unfinished"></translation>
+        <translation>Przeciągnij</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="254"/>
         <source>To Resize</source>
-        <translation type="unfinished"></translation>
+        <translation>Aby zmienić rozmiar</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="274"/>
         <source>+ Left Click</source>
-        <translation type="unfinished"></translation>
+        <translation>+ Lewe Kliknięcie</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="281"/>
         <source>To Move</source>
-        <translation type="unfinished"></translation>
+        <translation>Aby przesunąć</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="288"/>
         <source>+ Right Click</source>
-        <translation type="unfinished"></translation>
+        <translation>+ Prawe Kliknięcie</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="295"/>
         <source>NOTE: changes last only for the current session</source>
-        <translation type="unfinished"></translation>
+        <translation>UWAGA: zmiany obowiązują tylko dla bieżącej sesji</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="365"/>
@@ -83,54 +83,54 @@
     <message>
         <location filename="../mainwindow.ui" line="387"/>
         <source>Desktop 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Pulpit 1</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="410"/>
         <source>All Desktops</source>
-        <translation type="unfinished"></translation>
+        <translation>Wszystkie pulpity</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="436"/>
         <source>Format</source>
-        <translation type="unfinished"></translation>
+        <translation>Format</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="488"/>
         <source>Day</source>
-        <translation type="unfinished"></translation>
+        <translation>Dzień</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="517"/>
         <location filename="../mainwindow.ui" line="647"/>
         <source>Long</source>
-        <translation type="unfinished"></translation>
+        <translation>Długi</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="546"/>
         <source>Abbreviated name, e.g. Tu</source>
-        <translation type="unfinished"></translation>
+        <translation>Skrócona nazwa, np. Po</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="549"/>
         <location filename="../mainwindow.ui" line="679"/>
         <source>Short</source>
-        <translation type="unfinished"></translation>
+        <translation>Krótki</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="618"/>
         <source>Month</source>
-        <translation type="unfinished"></translation>
+        <translation>Miesiąc</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="676"/>
         <source>Abbreviated name, e.g. Oct</source>
-        <translation type="unfinished"></translation>
+        <translation>Skrócona nazwa, np. Sty</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="732"/>
         <source>Colors</source>
-        <translation type="unfinished"></translation>
+        <translation>Kolory</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="778"/>
@@ -145,32 +145,32 @@
         <location filename="../mainwindow.ui" line="1284"/>
         <location filename="../mainwindow.ui" line="1399"/>
         <source>...</source>
-        <translation type="unfinished"></translation>
+        <translation>...</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="893"/>
         <source>Color0 </source>
-        <translation type="unfinished"></translation>
+        <translation>Kolor0</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1005"/>
         <source>Color1 </source>
-        <translation type="unfinished"></translation>
+        <translation>Kolor1</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1117"/>
         <source>Color2 </source>
-        <translation type="unfinished"></translation>
+        <translation>Kolor2</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1232"/>
         <source>Color3 </source>
-        <translation type="unfinished"></translation>
+        <translation>Kolor3</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1347"/>
         <source>Color4 </source>
-        <translation type="unfinished"></translation>
+        <translation>Kolor4</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1455"/>
@@ -205,7 +205,7 @@
     <message>
         <location filename="../mainwindow.ui" line="1539"/>
         <source>Quit application</source>
-        <translation>Zamknij apliikację</translation>
+        <translation>Zakończ aplikację</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1542"/>
@@ -218,68 +218,68 @@
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="301"/>
+        <location filename="../mainwindow.cpp" line="302"/>
         <source>About MX Conky</source>
-        <translation type="unfinished"></translation>
+        <translation>O programie MX Conky</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="302"/>
+        <location filename="../mainwindow.cpp" line="303"/>
         <source>Version: </source>
         <translation>Wersja:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="303"/>
+        <location filename="../mainwindow.cpp" line="304"/>
         <source>GUI program for configuring Conky in MX Linux</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="305"/>
-        <source>Copyright (c) MX Linux</source>
-        <translation>Copyright (c) MX Linux</translation>
+        <translation>Narzędzie GUI do konfigurowania Conky w MX Linux.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="306"/>
+        <source>Copyright (c) MX Linux</source>
+        <translation>Prawa autorskie © MX Linux</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="307"/>
         <source>License</source>
         <translation>Licencja</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="307"/>
+        <location filename="../mainwindow.cpp" line="308"/>
         <source>Changelog</source>
         <translation>Dziennik zmian</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="308"/>
+        <location filename="../mainwindow.cpp" line="309"/>
         <source>Cancel</source>
         <translation>Anuluj</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="328"/>
+        <location filename="../mainwindow.cpp" line="329"/>
         <source>&amp;Close</source>
         <translation>&amp;Zamknij</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="347"/>
+        <location filename="../mainwindow.cpp" line="348"/>
         <source>MX Conky Help</source>
-        <translation type="unfinished"></translation>
+        <translation>Pomoc MX Conky</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
         <location filename="../main.cpp" line="56"/>
-        <location filename="../mainwindow.cpp" line="435"/>
+        <location filename="../mainwindow.cpp" line="436"/>
         <source>Select Conky Manager config file</source>
-        <translation type="unfinished"></translation>
+        <translation>Wybierz plik konfiguracyjny Menedżera Conky</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="73"/>
         <source>Conky Data Update</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktualizacja danych Conky</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="74"/>
         <source>The MX Conky data set has been updated. &lt;p&gt;&lt;p&gt;                                  Copy from the folder where it is located &lt;a href=&quot;/usr/share/mx-conky-data/themes&quot;&gt;/usr/share/mx-conky-data/themes&lt;/a&gt;                                   whatever you wish to your Home hidden conky folder &lt;a href=&quot;%1/.conky&quot;&gt;~/.conky&lt;/a&gt;.                                   Be careful not to overwrite any conkies you have changed.</source>
-        <translation type="unfinished"></translation>
+        <translation>Zestaw danych MX Conky został zaktualizowany. &lt;p&gt;&lt;p&gt;                                  Skopiuj z folderu, w którym się znajduje &lt;a href=&quot;/usr/share/mx-conky-data/themes&quot;&gt;/usr/share/mx-conky-data/themes&lt;/a&gt;                                   cokolwiek chcesz do ukrytego folderu Conky w twoim katalogu domowym &lt;a href=&quot;%1/.conky&quot;&gt;~/.conky&lt;/a&gt;.                                   Uważaj, aby nie nadpisać żadnych Conky, które już zmieniłeś i skonfigurowałeś.</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="100"/>
@@ -290,17 +290,17 @@
     <message>
         <location filename="../main.cpp" line="101"/>
         <source>Could not find conky-manager, please install it before running mx-conky</source>
-        <translation type="unfinished"></translation>
+        <translation>Nie można znaleźć Menedżera Conky, zainstaluj go przed uruchomieniem MX Conky</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="125"/>
         <source>No file was selected, quiting program</source>
-        <translation type="unfinished"></translation>
+        <translation>Nie wybrano pliku, kończenie programu</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="136"/>
         <source>You must run this program as normal user</source>
-        <translation type="unfinished"></translation>
+        <translation>Musisz uruchomić ten program jako zwykły użytkownik</translation>
     </message>
 </context>
 </TS>
